@@ -74,7 +74,7 @@ varimp <- function (object, mincriterion = 0, conditional = FALSE,
 
             ## if OOB == TRUE use only oob observations, otherwise use all observations in learning sample
             if(OOB){oob <- object@weights[[b]] == 0} else{ oob <- rep(TRUE, length(y))}
-            p <- .Call("R_predict", tree, inp, mincriterion, -1L, PACKAGE = "party")
+            p <- .Call(R_predict, tree, inp, mincriterion, -1L)
             eoob <- error(p, oob)
 
             ## for all variables (j = 1 ... number of variables) 
@@ -90,11 +90,9 @@ varimp <- function (object, mincriterion = 0, conditional = FALSE,
                         perm <- conditional_perm(ccl, xnames, input, tree, oob)
                     }
                     tmp@variables[[j]][which(oob)] <- tmp@variables[[j]][perm]
-                    p <- .Call("R_predict", tree, tmp, mincriterion, -1L,
-                       PACKAGE = "party")
+                    p <- .Call(R_predict, tree, tmp, mincriterion, -1L)
                 } else {
-                    p <- .Call("R_predict", tree, inp, mincriterion, as.integer(j),
-                               PACKAGE = "party")
+                    p <- .Call(R_predict, tree, inp, mincriterion, as.integer(j))
                 }
                 ## run through all rows of perror
                 perror[(per+(b-1)*nperm), j] <- (error(p, oob) - eoob)
@@ -132,8 +130,8 @@ varimpsurv <- function (object, mincriterion = 0, conditional = FALSE,
 
     pred <- function(tree, newinp, j = -1L) {
 
-        where <- R_get_nodeID(tree, inp, mincriterion)
-        wh <- .Call("R_get_nodeID", tree, newinp, mincriterion, as.integer(j), PACKAGE = "party")
+        where <- .R_get_nodeID(tree, inp, mincriterion)
+        wh <- .Call(R_get_nodeID, tree, newinp, mincriterion, as.integer(j))
         swh <- sort(unique(wh))
         RET <- vector(mode = "list", length = length(wh))
         for (i in 1:length(swh)) {
@@ -346,7 +344,7 @@ varimpAUC <- function(object, mincriterion = 0, conditional = FALSE,
             tree <- object@ensemble[[b]]
 
             if(OOB){oob <- object@weights[[b]] == 0} else{ oob <- rep(TRUE, length(xnames))}
-            p <- .Call("R_predict", tree, inp, mincriterion, -1L, PACKAGE = "party")
+            p <- .Call(R_predict, tree, inp, mincriterion, -1L)
             eoob <- error(p, oob)
 
             for(j in unique(varIDs(tree))){
@@ -361,11 +359,9 @@ varimpAUC <- function(object, mincriterion = 0, conditional = FALSE,
                         perm <- conditional_perm(ccl, xnames, input, tree, oob)
                     }
                     tmp@variables[[j]][which(oob)] <- tmp@variables[[j]][perm]
-                    p <- .Call("R_predict", tree, tmp, mincriterion, -1L,
-                       PACKAGE = "party")
+                    p <- .Call(R_predict, tree, tmp, mincriterion, -1L)
                 } else {
-                    p <- .Call("R_predict", tree, inp, mincriterion, as.integer(j),
-                               PACKAGE = "party")
+                    p <- .Call(R_predict, tree, inp, mincriterion, as.integer(j))
                 }
                 perror[(per+(b-1)*nperm), j] <- (error(p, oob) - eoob)
 
