@@ -19,5 +19,5 @@ int i_in_set(int i, int *iset, int p);
 int C_i_in_set(int i, SEXP set);
 void C_SampleSplitting(int n, double *prob, int *weights, int k);
 void C_remove_weights(SEXP subtree, int removestats);
-double* C_tempweights(int j, SEXP weights, SEXP fitmem, SEXP inputs);
+double* C_tempweights(int j, double *dweights, SEXP fitmem, SEXP inputs);
 void C_linexpcovReduce (SEXP x);
